@@ -14,7 +14,11 @@ import datetime
 import os
 
 ################################################################################
-#
+"""_getProxy
+
+   Wrapper function for getting a proxy object for a particular header.  Takes
+   care of the "try-except" structure.
+"""
 def _getProxy(header):
     try:
         p = header.proxy()
@@ -25,40 +29,47 @@ def _getProxy(header):
     return p
 
 ################################################################################
-'''
+"""CommandLineOption
+
     Base Class for handling command line options
-'''
+
+    Every option obect has an `args` attribute and a `kwargs` attribute that
+    define the option for the argparse module.  Additionally, every option
+    object has the `check` method and a `run` method.
+"""
 class CommandLineOption:
     args = ()  # to be overridden by the option
     kwargs = {}  # to be overriden by the option
 
-    '''
-    This method should check the relevant option and return True if the 
-    option should be processed, False otherwise
-    the 'opts' arg is the Values object returned by the OptParse parser.
-    if the option is present and stores a value that is needed when the option
-    is run, then the value should be squirreled away in an instance attribute
-    '''
+    ############################################################################
+    """check
+
+        This method should check the relevant option and return True if the 
+        option should be processed, False otherwise
+        the 'opts' arg is the Values object returned by the OptParse parser.
+        if the option is present and stores a value that is needed when the option
+        is run, then the value should be squirreled away in an instance attribute
+    """
     def check(self, opts):
         pass
 
-    '''
-    This method performs the actual option processing.  It does not return any
-    error codes- any errors should raise the CommandLineOptionError exception
-    the 'opts' arg will be the Values object returned by the OptParse parser.
-    the 'proxy' arg will be a proxy object for communicating with the blog
-    if necessary 
-    '''
+    ############################################################################
+    """run
+
+        This method performs the actual option processing.  It does not return any
+        error codes- any errors should raise the CommandLineOptionError exception
+        the 'opts' arg will be the Values object returned by the OptParse parser.
+        the 'proxy' arg will be a proxy object for communicating with the blog
+        if necessary 
+    """
     def run(self, header, opts):
         pass
         
 ################################################################################
-'''
-    DeletePost
+"""DeletePost
 
-        Define class to handle deleting posts from a blog.
-
-'''
+    Define class to handle deleting posts from a blog.
+"""
 class DeletePost(CommandLineOption):
     args = ('-d', '--delete')
     kwargs = {
@@ -89,9 +100,10 @@ class DeletePost(CommandLineOption):
         return None
 
 ################################################################################
-'''
-    DeleteComment
-'''
+"""DeleteComment
+
+   Option for deleting a comment from a blog. 
+"""
 class DeleteComment(CommandLineOption):
     args = ('-D', '--deletecomment')
     kwargs = {
@@ -121,12 +133,11 @@ class DeleteComment(CommandLineOption):
         return None
 
 ################################################################################
-'''
-    GetRecentTitles
+"""GetRecentTitles
 
-        Define class to handle retrieving recent blog post info and displaying
-        it to stdout.
-'''
+    Define class to handle retrieving recent blog post info and displaying
+    it to stdout.
+"""
 class GetRecentTitles(CommandLineOption):
     args = ('-t', '--recent-titles')
     kwargs = {
@@ -180,13 +191,11 @@ class GetRecentTitles(CommandLineOption):
 
 
 ################################################################################
-'''
-    GetCategories
+"""GetCategories
 
-        Define class to handle retrieving category list from a blog and 
-        displaying is to stdout.
-
-'''
+    Define class to handle retrieving category list from a blog and 
+    displaying is to stdout.
+"""
 class GetCategories(CommandLineOption):
     args = ('-C', '--Categories')
     kwargs = {
@@ -226,22 +235,20 @@ class GetCategories(CommandLineOption):
         return None
 
 ################################################################################
-''' 
-    AddCategory
+"""AddCategory
 
-        Define class to handle adding a category to a blog
-
-'''
+    Define class to handle adding a category to a blog
+"""
 class AddCategory(CommandLineOption):
     args = ('-n', '--new-categories')
     kwargs = {
               'action' : 'store',
               'dest' : "newcat",
-              'help' : """
+              'help' : '''
 Add NEWCAT category to a blog.  NEWCAT can specifiy mutlitple levels of new
 categories using a dot notation to separate subcategories, eg
 "newcat1.subcata.subcatb".
-"""
+'''
              }
 
     def check(self, opts):
@@ -281,10 +288,10 @@ categories using a dot notation to separate subcategories, eg
         return None
 
 ################################################################################
-'''
-    UploadMediaFile
+"""UploadMediaFile
 
-'''
+    Implements option to upload a media file to a blog, such as a jpg file.
+"""
 class UploadMediaFile(CommandLineOption):
     args = ('-u', '--uploadmedia')
     kwargs = {
@@ -304,7 +311,7 @@ class UploadMediaFile(CommandLineOption):
     def run(self, header, opts):
         try:
             proxy = _getProxy(header)
-            uf = utils.chkfile(self.uploadfile)
+            uf = utils.chkFile(self.uploadfile)
             print "Attempting to upload '%s'..." % uf
             res = proxy.upload(uf)
         except utils.UtilsError, err:
@@ -316,28 +323,26 @@ class UploadMediaFile(CommandLineOption):
         return None
 
 ################################################################################
-'''
-    GetPost
+"""GetPost
        
-        Define class to handle retrieving a post from a blog given the post's
-        ID and printing the result to stdout.
-     
-'''
+    Define class to handle retrieving a post from a blog given the post's
+    ID and printing the result to stdout.
+"""
 class GetPost(CommandLineOption):
     args = ('-g', '--getpost')
     kwargs = {
               'action' : 'store',
               'dest' : 'get_postid',
               'metavar' : 'POSTID',
-              'help' : """
+              'help' : '''
 Retrieves post POSTID from a blog and writes it to STDOUT using Markdown
 formatting.  A header is also created, meaning a file capture could be used for
 updating with blogtool.  
-"""            
+'''            
              }
 
-    catID = 0
-    parentID = 1
+    CATID = 0
+    CATPARENTID = 1
 
     def check(self, opts):
         if opts.get_postid:
@@ -361,8 +366,9 @@ updating with blogtool.
             sys.exit()
 
         if post['mt_text_more']:
+            more = "<!--%s-->" % (post['wp_more_text'] or "more")
             text = html2md.convert("%s%s%s" % (post['description'], 
-                                               "<!--more-->",
+                                               more,
                                                post['mt_text_more']))
         else:
             text = html2md.convert(post['description'])
@@ -372,6 +378,13 @@ updating with blogtool.
         header_str += 'CATEGORIES: %s\n' % self._buildCatStr(post['categories'])
         if post['mt_keywords']:
             header_str += 'TAGS: %s\n' % post['mt_keywords']
+        if post['mt_excerpt']:
+            if any([c in post['mt_excerpt'] for c in [',','\n','{','}']]):
+                header_str += 'EXCERPT: """%s"""' % post['mt_excerpt']
+            else:
+                header_str += 'EXCERPT: %s' % post['mt_excerpt']
+            header_str = header_str.rstrip() + '\n' # ensure header is terminated
+
         print (header_str + '\n' + text).encode("utf8")
         return None
 
@@ -387,7 +400,7 @@ updating with blogtool.
             cat_s = catlist[0]
         else:
             for cat in catlist:
-               if blogcats_d[cat][self.parentID] == '0':
+               if blogcats_d[cat][self.CATPARENTID] == '0':
                    if cat_s == '':
                       cat_s += "%s" % cat
                    else:
@@ -396,37 +409,37 @@ updating with blogtool.
                    cat_s += ".%s" % cat
         return cat_s
 
+    ############################################################################
+    """_sortCats
+   
+        Sorts catlist from category to lowest subcategory.  If multiple
+        subcategories have a common parent, then the category hierarchy is
+        duplicated and added to the list with the new subcategory.
+    """
     def _sortCats(self, catlist, bcats_d):
-        ''' Sorts catlist from category to lowest subcategory.  If multiple
-            subcategories have a common parent, then the category hierarchy is
-            duplicated and added to the list with the new subcategory.
-        '''
         sortedcats = []
         while len(catlist) != 0:
             for cat in catlist[:]:
-                cat_parent_id = bcats_d[cat][self.parentID]
+                cat_parent_id = bcats_d[cat][self.CATPARENTID]
                 if cat_parent_id == '0':
                     sortedcats.append(cat)
                     catlist.remove(cat)
                 else:
                     enumerated_seq = list(enumerate(sortedcats))
                     for i, s_cat in enumerated_seq:
-                        if cat_parent_id == bcats_d[s_cat][self.catID]:
+                        if cat_parent_id == bcats_d[s_cat][self.CATID]:
                             # does this subcategory have the same parent as 
                             # another subcatgory?
                             if len(sortedcats) > i+1 and \
-                               bcats_d[sortedcats[i+1]][self.parentID] == \
-                                                                  cat_parent_id:
+                               bcats_d[sortedcats[i+1]][self.CATPARENTID] == cat_parent_id:
                                 # find the top of the category hierarchy
                                 # i is the index of the parent of cat
-                                while bcats_d[sortedcats[i]][self.parentID] != \
-                                                                            '0':
+                                while bcats_d[sortedcats[i]][self.CATPARENTID] != '0':
                                     i = i - 1
                                 j = i # mark insertion point into sortedlist
                                 # copy category hierarchy
                                 hierarchycopy = []
-                                while bcats_d[sortedcats[i]][self.parentID] != \
-                                      cat_parent_id:
+                                while bcats_d[sortedcats[i]][self.CATPARENTID] != cat_parent_id:
                                     hierarchycopy.insert(0, sortedcats[i])
                                     i = i + 1
                                 hierarchycopy.insert(0, cat) # add new cat
@@ -439,8 +452,7 @@ updating with blogtool.
                                 sortedcats.insert(i+1, cat)
                                 catlist.remove(cat)
                                 break
-                        elif bcats_d[cat][self.catID] == \
-                                                  bcats_d[s_cat][self.parentID]:
+                        elif bcats_d[cat][self.CATID] == bcats_d[s_cat][self.CATPARENTID]:
                             sortedcats.insert(i-1, cat)
                             catlist.remove(cat)
                             break
@@ -448,18 +460,19 @@ updating with blogtool.
                     
 
 ################################################################################
-'''
-    GetComments
-'''
+"""GetComments
+
+    Option to retrieve comments for blog post.
+"""
 class GetComments(CommandLineOption):
     args = ('-r', '--readcomments')
     kwargs = {
               'action' : 'store',
               'dest' : 'comments_postid',
               'metavar' : 'POSTID',
-              'help' : """
+              'help' : '''
 Retrieves the comments for post POSTID.
-"""
+'''
              }
 
     def check(self, opts):
@@ -492,22 +505,21 @@ Retrieves the comments for post POSTID.
         return None
 
 ################################################################################
-'''
-    EditComment
+"""EditComment
 
     Class to handle editing of comments.
-'''
+"""
 class EditComment(CommandLineOption):
     args = ('--editcomment', )
     kwargs = {
               'action' : 'store',
               'dest' : 'commentid',
-              'help' : """
+              'help' : '''
 Edit comment COMMENTID already on the blog.  The comment will be downloaded and
 an editor will be launched with the comment text formatted into Markdown syntax.
 A header is also generated with the metadata from the blog in it so it can also
 be edited, for instance to approve a comment held in moderation.
-"""
+'''
              }
 
     def check(self, opts):
@@ -552,12 +564,10 @@ be edited, for instance to approve a comment held in moderation.
         return None
 
 ################################################################################
-'''
-    SetConfigFile
+"""SetConfigFile
 
-        Define class to handle parsing of a config file for blogtool.
-
-'''
+    Define class to handle parsing of a config file for blogtool.
+"""
 class SetConfigFile(CommandLineOption):
     args = ('-c', '--config')
     kwargs = { 
@@ -582,7 +592,7 @@ class SetConfigFile(CommandLineOption):
                 return 
         else:
            try:
-               rcf = utils.chkfile(self.configfile)
+               rcf = utils.chkFile(self.configfile)
            except utils.UtilsError, err:
                print "Config file not found: %s" % self.configfile
                sys.exit(1)
@@ -602,23 +612,21 @@ class SetConfigFile(CommandLineOption):
         return None
 
 ################################################################################
-'''
-    SetAddCategory
+"""SetAddCategory
 
-        Define class that sets flag indicating to add categories specified in
-        blog post that are not on the blog.
-
-'''
+    Define class that sets flag indicating to add categories specified in
+    blog post that are not on the blog.
+"""
 class SetAddCategory(CommandLineOption):
     args = ('-a', '--add-categories')
     kwargs = {
               'action' : 'store_true',
               'dest' : 'addpostcats',
               'default' : False,
-              'help' : """
+              'help' : '''
 A flag option that causes categories specified in a post file to be added to the
 blog's category list if they do not already exist.  
-"""
+'''
              }
 
     def check(self, opts):
@@ -628,22 +636,21 @@ blog's category list if they do not already exist.
         return 'runeditor'
 
 ################################################################################
-'''
-    SetBlogname
+"""SetBlogname
 
-        Define class for option that specfies blog to use if multiple blogs 
-        setup in config file.
-'''
+    Define class for option that specfies blog to use if multiple blogs 
+    setup in config file.
+"""
 class SetBlogname(CommandLineOption):
     args = ('-b','--blog')
     kwargs = {
               'action' : 'store',
               'dest' : 'blogname',
-              'help' : """
+              'help' : '''
 Specifies a blog to execute a command against for deleting posts or comments,
 retrieving category lists or posts or comments, etc.  The name must correspond
 to a name in ~/.btrc or a config file specified on the command line.
-"""  
+'''  
              }
 
     def check(self, opts):
@@ -662,23 +669,22 @@ to a name in ~/.btrc or a config file specified on the command line.
         return None
 
 ################################################################################
-'''
-    SetPosttime
+"""SetPosttime
 
-        Define class for option to schedule when a post should be published.
-'''
+    Define class for option to schedule when a post should be published.
+"""
 class SetPosttime(CommandLineOption):
     args = ('-s', '--schedule')
     kwargs = {
               'action' : 'store',
               'dest' : 'posttime',
               'metavar' : 'TIMESTR',
-              'help' : """
+              'help' : '''
 Sets the time to publish post.  TIMESTR supports a number of formats:  YYYYMMDDThh:mm, 
 YYYYMMDDThh:mmAM/PM, YYYYMMDDThh:mm:ss, YYYYMMDDThh:mm:ssAM/PM,
 Month Day, Year hour:min, Month Day, Year hour:min AM/PM, MM/DD/YYYY hh:mm,
 MM/DD/YYYY hh:mmAM/PM, hh:mm MM/DD/YYYY, hh:mmAM/PM MM/DD/YYYY
-""" 
+''' 
              }
 
     def check(self, opts):
@@ -691,11 +697,10 @@ MM/DD/YYYY hh:mmAM/PM, hh:mm MM/DD/YYYY, hh:mmAM/PM MM/DD/YYYY
         return 'runeditor'
 
 ################################################################################
-'''
-    SetNoPublish
+"""SetNoPublish
 
-        Define class for option to write post to blog as a draft.
-'''
+    Define class for option to write post to blog as a draft.
+"""
 class SetNoPublish(CommandLineOption):
     args = ('--draft', )
     kwargs = {
@@ -715,19 +720,21 @@ class SetNoPublish(CommandLineOption):
         return 'runeditor'
 
 ################################################################################
-'''
-    SetAllBlogs
-'''
+"""SetAllBlogs
+
+   Option to make blogtool execute a command on all blogs in a configuration
+   file.
+"""
 class SetAllBlogs(CommandLineOption):
     args = ('-A', '--allblogs')
     kwargs = {
               'action' : "store_true",
               'dest' : "allblogs",
               'default' : False,
-              'help' : """
+              'help' : '''
 A flag option that will cause the post to be published to all blogs listed in
 the rc file.
-"""
+'''
              }
 
     def check(self, opts):
@@ -740,9 +747,10 @@ the rc file.
         return 'runeditor'
 
 ################################################################################
-'''
-    SetPostComment
-'''
+"""SetPostComment
+
+    Option to write a comment to a blog.
+"""
 class SetPostComment(CommandLineOption):
     args = ('--comment', )
     kwargs = {
@@ -751,10 +759,10 @@ class SetPostComment(CommandLineOption):
               'default' : False,
               'metavar' : ('POSTID', 'COMMENTID'),
               'nargs' : 2,
-              'help' : """
+              'help' : '''
 Post text from file as a comment to post POSTID.  If the comment is in answer to
 another comment, supply the COMMENTID, otherwise set it to 0.
-"""
+'''
              }
 
     def check(self, opts):
@@ -772,19 +780,20 @@ another comment, supply the COMMENTID, otherwise set it to 0.
         return 'runeditor'
 
 ################################################################################
-'''
-    SetCharset
-'''
+"""SetCharset
+
+    Option to set the encoding for text in a blog post.
+"""
 class SetCharset(CommandLineOption):
     args = ('--charset', )
     kwargs = {
               'action' : 'store',
               'dest' : 'charset',
               'metavar' : 'CHARSET',
-              'help' : """
+              'help' : '''
 Set the CHARSET to use to decode the post text prior to running the text through
 markdown.
-"""
+'''
              }
 
     def check(self, opts):
@@ -799,9 +808,10 @@ markdown.
         return 'runeditor' 
 
 ################################################################################
-'''
-    GetVersion
-'''
+"""GetVersion
+
+    Option to display version information.
+"""
 class GetVersion(CommandLineOption):
     args = ('--version',)
     kwargs = {
@@ -818,9 +828,11 @@ class GetVersion(CommandLineOption):
 
 
 ################################################################################
-'''
-    OptionProcessor
-'''
+"""OptionProcessor
+    
+    Class that initializes the option parsing and coordinates executing the
+    various options.
+"""
 class OptionProcessor:
     def __init__(self):
         self.o_list = []
