@@ -1,5 +1,10 @@
 import sys
 
+################################################################################
+"""getProxy
+
+    Returns an instance of the appropriate proxy object based on the blog type.
+"""
 def getProxy(blogtype, url, user, password):
     module_name = "%s_proxy" % blogtype
     try:
